"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deserializeOrder = exports.serializeOrdersQueryOptions = exports.getFulfillOfferPayload = exports.getFulfillListingPayload = exports.getFulfillmentDataPath = exports.getBuildCollectionOfferPayload = exports.getPostCollectionOfferPayload = exports.getRefreshMetadataPath = exports.getNFTPath = exports.getListNFTsByAccountPath = exports.getListNFTsByContractPath = exports.getListNFTsByCollectionPath = exports.getCollectionOffersPath = exports.getPostCollectionOfferPath = exports.getBuildOfferPath = exports.getCollectionPath = exports.getOrdersAPIPath = exports.DEFAULT_SEAPORT_CONTRACT_ADDRESS = void 0;
const constants_1 = require("@opensea/seaport-js/lib/constants");
const ethers_1 = require("ethers");
const utils_1 = require("../utils");
exports.DEFAULT_SEAPORT_CONTRACT_ADDRESS = constants_1.CROSS_CHAIN_SEAPORT_V1_5_ADDRESS;
const getOrdersAPIPath = (chain, protocol, side) => {
    const sidePath = side === "ask" ? "listings" : "offers";
    return `/v2/orders/${chain}/${protocol}/${sidePath}`;
};
exports.getOrdersAPIPath = getOrdersAPIPath;
const getCollectionPath = (slug) => {
    return `/api/v1/collection/${slug}`;
};
exports.getCollectionPath = getCollectionPath;
const getBuildOfferPath = () => {
    return `/v2/offers/build`;
};
exports.getBuildOfferPath = getBuildOfferPath;
const getPostCollectionOfferPath = () => {
    return `/v2/offers`;
};
exports.getPostCollectionOfferPath = getPostCollectionOfferPath;
const getCollectionOffersPath = (slug) => {
    return `/v2/offers/collection/${slug}`;
};
exports.getCollectionOffersPath = getCollectionOffersPath;
const getListNFTsByCollectionPath = (slug) => {
    return `/v2/collection/${slug}/nfts`;
};
exports.getListNFTsByCollectionPath = getListNFTsByCollectionPath;
const getListNFTsByContractPath = (chain, address) => {
    return `/v2/chain/${chain}/contract/${address}/nfts`;
};
exports.getListNFTsByContractPath = getListNFTsByContractPath;
const getListNFTsByAccountPath = (chain, address) => {
    return `/v2/chain/${chain}/account/${address}/nfts`;
};
exports.getListNFTsByAccountPath = getListNFTsByAccountPath;
const getNFTPath = (chain, address, identifier) => {
    return `/v2/chain/${chain}/contract/${address}/nfts/${identifier}`;
};
exports.getNFTPath = getNFTPath;
const getRefreshMetadataPath = (chain, address, identifier) => {
    return `/v2/chain/${chain}/contract/${address}/nfts/${identifier}/refresh`;
};
exports.getRefreshMetadataPath = getRefreshMetadataPath;
const getPostCollectionOfferPayload = (collectionSlug, protocol_data) => {
    return {
        criteria: {
            collection: { slug: collectionSlug },
        },
        protocol_data,
        protocol_address: exports.DEFAULT_SEAPORT_CONTRACT_ADDRESS,
    };
};
exports.getPostCollectionOfferPayload = getPostCollectionOfferPayload;
const getBuildCollectionOfferPayload = (offererAddress, quantity, collectionSlug) => {
    return {
        offerer: offererAddress,
        quantity,
        criteria: {
            collection: {
                slug: collectionSlug,
            },
        },
        protocol_address: exports.DEFAULT_SEAPORT_CONTRACT_ADDRESS,
    };
};
exports.getBuildCollectionOfferPayload = getBuildCollectionOfferPayload;
const getFulfillmentDataPath = (side) => {
    const sidePath = side === "ask" ? "listings" : "offers";
    return `/v2/${sidePath}/fulfillment_data`;
};
exports.getFulfillmentDataPath = getFulfillmentDataPath;
const getFulfillListingPayload = (fulfillerAddress, order_hash, protocolAddress, chain) => {
    return {
        listing: {
            hash: order_hash,
            chain,
            protocol_address: protocolAddress,
        },
        fulfiller: {
            address: fulfillerAddress,
        },
    };
};
exports.getFulfillListingPayload = getFulfillListingPayload;
const getFulfillOfferPayload = (fulfillerAddress, order_hash, protocolAddress, chain) => {
    return {
        offer: {
            hash: order_hash,
            chain,
            protocol_address: protocolAddress,
        },
        fulfiller: {
            address: fulfillerAddress,
        },
    };
};
exports.getFulfillOfferPayload = getFulfillOfferPayload;
const serializeOrdersQueryOptions = (options) => {
    var _a;
    return {
        limit: options.limit,
        cursor: options.cursor,
        payment_token_address: options.paymentTokenAddress,
        maker: options.maker,
        taker: options.taker,
        owner: options.owner,
        bundled: options.bundled,
        include_bundled: options.includeBundled,
        listed_after: options.listedAfter,
        listed_before: options.listedBefore,
        token_ids: (_a = options.tokenIds) !== null && _a !== void 0 ? _a : [options.tokenId],
        asset_contract_address: options.assetContractAddress,
        order_by: options.orderBy,
        order_direction: options.orderDirection,
        only_english: options.onlyEnglish,
    };
};
exports.serializeOrdersQueryOptions = serializeOrdersQueryOptions;
const deserializeOrder = (order) => {
    return {
        createdDate: order.created_date,
        closingDate: order.closing_date,
        listingTime: order.listing_time,
        expirationTime: order.expiration_time,
        orderHash: order.order_hash,
        maker: (0, utils_1.accountFromJSON)(order.maker),
        taker: order.taker ? (0, utils_1.accountFromJSON)(order.taker) : null,
        protocolData: order.protocol_data,
        protocolAddress: order.protocol_address,
        currentPrice: ethers_1.BigNumber.from(order.current_price),
        makerFees: order.maker_fees.map(({ account, basis_points }) => ({
            account: (0, utils_1.accountFromJSON)(account),
            basisPoints: basis_points,
        })),
        takerFees: order.taker_fees.map(({ account, basis_points }) => ({
            account: (0, utils_1.accountFromJSON)(account),
            basisPoints: basis_points,
        })),
        side: order.side,
        orderType: order.order_type,
        cancelled: order.cancelled,
        finalized: order.finalized,
        markedInvalid: order.marked_invalid,
        clientSignature: order.client_signature,
        makerAssetBundle: (0, utils_1.assetBundleFromJSON)(order.maker_asset_bundle),
        takerAssetBundle: (0, utils_1.assetBundleFromJSON)(order.taker_asset_bundle),
        remainingQuantity: order.remaining_quantity,
    };
};
exports.deserializeOrder = deserializeOrder;
//# sourceMappingURL=utils.js.map